% This is the AIC/BIC-based selections for Bernstein sieve for SMLE on freez and valdez data.

% Import the claims data
start=tic;
Data = importdata('LOSSDATA.txt');
vars = fieldnames(Data);
for i = 1:length(vars)
    assignin('base', vars{i}, Data.(vars{i}));
end


X = data(:,1);  % loss (censored)
Y = data(:,2);  % expense
d = data(:,4);  % zeros(length(X),1); %  % censoring dummy

N=length(X);

%Init values 
lamXqmle=14443.05;
thetXqmle=1.135;
lamYqmle=15133.34;
thetYqmle=2.223;

U = 1 - (1+X/lamXqmle).^(-thetXqmle);   % Pareto CDF
V = 1 - (1+Y/lamYqmle).^(-thetYqmle);


Options = optimset('TolX',1e-6,'TolFun', 1e-6,  'MaxIter', 1e6, 'MaxFunEvals', 1e6, 'Display', 'off');


for k=2:10
    tic
    nchoose=zeros(k,1);

    for j = 1:k
        nchoose(j)=nchoosek(k-1,j-1);
    end

    In = zeros(k,k); %empirical histogram

    count=1/N;

    for l = 1:N
        i=floor(U(l)*k)+1;
        j=floor(V(l)*k)+1;
        In(i,j) = In(i,j) + count;
    end

    In=reshape(In,k*k,1);
    In(In==0)=eps;
    
    Init=log([lamXqmle; thetXqmle; lamYqmle; thetYqmle; In]);


    [SMLEcoef_full, logLSMLE]=fminunc(@AppLoglikelihood_SMLE_Bernstein, Init, Options, X, Y, d, k, nchoose);

    %Estimated parameters
    lamX=exp(SMLEcoef_full(1));
    thetX=exp(SMLEcoef_full(2));
    lamY=exp(SMLEcoef_full(3));
    thetY=exp(SMLEcoef_full(4));

    %initial value for next k 

    temp=exp(SMLEcoef_full(5:end));
    temp=temp/sum(temp);
    I=reshape(temp,k,k);

    rest=1/k;
    penalty=sum((sum(I,1)-rest).^2+(sum(I,2)'-rest).^2);

    const=1e6;
    logLSMLE=-logLSMLE+const*penalty; %logL correction for penalty, typically negligible relativey to the value of logL

    npar=length(SMLEcoef_full)-(2*k-1); %number of free parameters, 2*k restrictions but one redundant due to linear dependence

    BIC=-2*logLSMLE+npar*log(N);
    AIC=-2*logLSMLE+2*npar;

    fprintf('%i %7.5f %7.5f %7.5f %7.5f %7.5f %7.5f %7.5f %7.5f\n',k,lamX,thetX,lamY,thetY,logLSMLE,AIC,BIC,toc);

end

fprintf('Total run-time %f\n',toc(start))