Data = importdata('LossData.txt');
vars = fieldnames(Data);
for i = 1:length(vars)
    assignin('base', vars{i}, Data.(vars{i}));
end


X = data(:,1);  % loss (censored)
Y = data(:,2);  % expense
d = data(:,4);%zeros(length(X),1); %  % censoring dummy

N=length(X);

Options = optimset('TolX', 1e-6, 'TolFun', 1e-6,'MaxIter', 1e6, 'MaxFunEvals', 1e6,  'Display', 'off');

tic
fprintf('==========================  QMLE ============================\n');

%starting values
lamX=log(14000); % Tab.5 of Frees and Valdez 99
thetX=log(1);
lamY=log(15000);
thetY=log(2);



[OptQMLE, logLQMLE] = fminunc(@AppLoglikelihood_QMLE, [lamX; thetX; lamY; thetY], Options, X, Y , d);

lamX=exp(OptQMLE(1));
thetX=exp(OptQMLE(2));
lamY=exp(OptQMLE(3));
thetY=exp(OptQMLE(4));

% Asy var matrix calculation


% scores from Mathematica

sX_l = ((d-1)*lamX + thetX.*X)./(lamX.*(lamX + X));
sX_t = (1-d)./thetX + log(lamX./(lamX+X));
sY_l = (-lamY+thetY.*Y)./(lamY.*(lamY+Y));
sY_t = 1/thetY + log(lamY./(lamY + Y));

s = [sX_l sX_t sY_l sY_t];

ss = s'*s;

VarQMLE = inv(ss);


fprintf('Par      | LamX         | ThetX    | LamY         | ThetY \n');
fprintf('Est      | %f | %f | %f | %f\n', exp(OptQMLE(1:4)));
fprintf('StEr     | %f  | %f | %f  | %f\n', [sqrt(VarQMLE(1,1)), sqrt(VarQMLE(2,2)), sqrt(VarQMLE(3,3)), sqrt(VarQMLE(4,4))]);
fprintf('LogL     | %f \n', -logLQMLE);
fprintf('Time     | %f \n', toc);

%%

fprintf('==========================  FMLE Frank ============================\n');


%Full MLE: minimize the negative of log-likelihood


rho = 3;     % rho = - alpha, where alpha is used in Frees and Valdez 98

%initial value for marginals from QMLE estimates
[OptFMLE_F, logLFMLE_F] = fminunc(@AppLoglikelihood_FMLE_Frank, [OptQMLE; rho], Options, X, Y ,d);

lamX=exp(OptFMLE_F(1));
thetX=exp(OptFMLE_F(2));
lamY=exp(OptFMLE_F(3));
thetY=exp(OptFMLE_F(4));
rho = OptFMLE_F(5);

% Asy var matrix calculation

%from Mathematica

sX_l =((-1)+exp(1).^(rho.*(lamX.*(lamX+X).^(-1)).^thetX)).^(-1).*(exp(1).^rho+(-1).*exp(1).^(rho.*(1+(lamX.*(lamX+X).^(-1)).^thetX))+(-1).*exp(1).^(rho.*(1+(lamY.*( ...
    lamY+Y).^(-1)).^thetY))+exp(1).^(rho.*((lamX.*(lamX+X).^(-1)).^thetX+(lamY.*(lamY+Y).^(-1)).^thetY))).^(-1).*lamX.^(-1).*(lamX+X).^(-1).*(2.*((-1)+d).*exp(1).^( ...
    rho.*(1+(lamX.*(lamX+X).^(-1)).^thetX)).*(lamX+(-1).*thetX.*X)+exp(1).^(rho.*(1+(lamX.*(lamX+X).^(-1)).^thetX+(lamY.*(lamY+Y).^(-1)).^thetY)).*(lamX+(-1).*d.* ...
    lamX+thetX.*X.*((-1)+d+(-1).*rho.*(lamX.*(lamX+X).^(-1)).^thetX))+(-1).*((-1)+d).*exp(1).^(rho+2.*rho.*(lamX.*(lamX+X).^(-1)).^thetX).*(lamX+thetX.*X.*((-1)+ ...
    rho.*(lamX.*(lamX+X).^(-1)).^thetX))+((-1)+d).*exp(1).^(rho.*(2.*(lamX.*(lamX+X).^(-1)).^thetX+(lamY.*(lamY+Y).^(-1)).^thetY)).*(lamX+thetX.*X.*((-1)+rho.*( ...
    lamX.*(lamX+X).^(-1)).^thetX))+((-1)+d).*exp(1).^(rho.*(1+(lamY.*(lamY+Y).^(-1)).^thetY)).*(lamX+(-1).*thetX.*X.*(1+rho.*(lamX.*(lamX+X).^(-1)).^thetX))+((-1)+ ...
    d).*exp(1).^rho.*((-1).*lamX+thetX.*X.*(1+rho.*(lamX.*(lamX+X).^(-1)).^thetX))+exp(1).^(rho.*((lamX.*(lamX+X).^(-1)).^thetX+(lamY.*(lamY+Y).^(-1)).^thetY)).*( ...
    lamX+(-1).*d.*lamX+thetX.*X.*((-1)+d+rho.*(lamX.*(lamX+X).^(-1)).^thetX)));
sX_t = (1+(-1).*d).*thetX.^(-1)+(1+(-1).*d+(-1).*((-1)+exp(1).^(rho.*(lamX.*(lamX+X).^(-1)).^thetX)).^(-1).*(exp(1).^rho+(-1).*exp(1).^(rho.*(1+(lamX.*(lamX+X).^(-1)) ...
    .^thetX))+(-1).*exp(1).^(rho.*(1+(lamY.*(lamY+Y).^(-1)).^thetY))+exp(1).^(rho.*((lamX.*(lamX+X).^(-1)).^thetX+(lamY.*(lamY+Y).^(-1)).^thetY))).^(-1).*((-1).*(( ...
    -1)+d).*exp(1).^rho+((-1)+d).*exp(1).^(rho+2.*rho.*(lamX.*(lamX+X).^(-1)).^thetX)+((-1)+d).*exp(1).^(rho.*(1+(lamY.*(lamY+Y).^(-1)).^thetY))+(-1).*exp(1).^( ...
    rho.*((lamX.*(lamX+X).^(-1)).^thetX+(lamY.*(lamY+Y).^(-1)).^thetY))+exp(1).^(rho.*(1+(lamX.*(lamX+X).^(-1)).^thetX+(lamY.*(lamY+Y).^(-1)).^thetY))+(-1).*((-1)+ ...
    d).*exp(1).^(rho.*(2.*(lamX.*(lamX+X).^(-1)).^thetX+(lamY.*(lamY+Y).^(-1)).^thetY))).*rho.*(lamX.*(lamX+X).^(-1)).^thetX).*log(lamX.*(lamX+X).^(-1));
sY_l = (exp(1).^rho+(-1).*exp(1).^(rho.*(1+(lamX.*(lamX+X).^(-1)).^thetX))+(-1).*exp(1).^(rho.*(1+(lamY.*(lamY+Y).^(-1)).^thetY))+exp(1).^(rho.*((lamX.*(lamX+X).^(-1)) ...
    .^thetX+(lamY.*(lamY+Y).^(-1)).^thetY))).^(-1).*lamY.^(-1).*(lamY+Y).^(-1).*(exp(1).^(rho.*(1+(lamY.*(lamY+Y).^(-1)).^thetY)).*(lamY+thetY.*Y.*((-1)+rho.*( ...
    lamY.*(lamY+Y).^(-1)).^thetY))+(-1).*exp(1).^(rho.*((lamX.*(lamX+X).^(-1)).^thetX+(lamY.*(lamY+Y).^(-1)).^thetY)).*(lamY+thetY.*Y.*((-1)+rho.*(lamY.*(lamY+Y).^( ...
    -1)).^thetY))+exp(1).^rho.*((-1).*lamY+thetY.*Y.*(1+(-1).*((-1)+d).*rho.*(lamY.*(lamY+Y).^(-1)).^thetY))+exp(1).^(rho.*(1+(lamX.*(lamX+X).^(-1)).^thetX)).*( ...
    lamY+thetY.*Y.*((-1)+((-1)+d).*rho.*(lamY.*(lamY+Y).^(-1)).^thetY)));
sY_t = thetY.^(-1)+log(lamY)+log((lamY+Y).^(-1))+(-1).*(exp(1).^rho+(-1).*exp(1).^(rho.*(1+(lamX.*(lamX+X).^(-1)).^thetX))+(-1).*exp(1).^(rho.*(1+(lamY.*(lamY+Y).^(-1) ...
    ).^thetY))+exp(1).^(rho.*((lamX.*(lamX+X).^(-1)).^thetX+(lamY.*(lamY+Y).^(-1)).^thetY))).^(-1).*(((-1)+d).*exp(1).^rho+(-1).*((-1)+d).*exp(1).^(rho.*(1+(lamX.*( ...
    lamX+X).^(-1)).^thetX))+(-1).*exp(1).^(rho.*(1+(lamY.*(lamY+Y).^(-1)).^thetY))+exp(1).^(rho.*((lamX.*(lamX+X).^(-1)).^thetX+(lamY.*(lamY+Y).^(-1)).^thetY))).* ...
    rho.*(lamY.*(lamY+Y).^(-1)).^thetY.*log(lamY.*(lamY+Y).^(-1));
s_r = (exp(1).^rho+(-1).*exp(1).^(rho.*(1+(lamX.*(lamX+X).^(-1)).^thetX))+(-1).*exp(1).^(rho.*(1+(lamY.*(lamY+Y).^(-1)).^thetY))+exp(1).^(rho.*((lamX.*(lamX+X).^(-1)) ...
    .^thetX+(lamY.*(lamY+Y).^(-1)).^thetY))).^(-1).*(d.*((-1)+exp(1).^(rho.*(lamX.*(lamX+X).^(-1)).^thetX)).^(-1).*((-1).*exp(1).^(rho.*(1+(lamY.*(lamY+Y).^(-1)) ...
    .^thetY)).*(lamY.*(lamY+Y).^(-1)).^thetY+(-1).*exp(1).^(rho.*(2.*(lamX.*(lamX+X).^(-1)).^thetX+(lamY.*(lamY+Y).^(-1)).^thetY)).*((-1)+(lamY.*(lamY+Y).^(-1)) ...
    .^thetY)+exp(1).^(rho.*(1+(lamX.*(lamX+X).^(-1)).^thetX+(lamY.*(lamY+Y).^(-1)).^thetY)).*((-1).*(lamX.*(lamX+X).^(-1)).^thetX+(lamY.*(lamY+Y).^(-1)).^thetY)+ ...
    exp(1).^(rho.*((lamX.*(lamX+X).^(-1)).^thetX+(lamY.*(lamY+Y).^(-1)).^thetY)).*((-1)+(lamX.*(lamX+X).^(-1)).^thetX+(lamY.*(lamY+Y).^(-1)).^thetY))+(-1).*((-1)+d) ...
    .*((-1)+exp(1).^rho).^(-1).*rho.^(-1).*(exp(1).^(rho.*(1+(lamY.*(lamY+Y).^(-1)).^thetY)).*(1+rho.*((-1)+(lamX.*(lamX+X).^(-1)).^thetX+(-1).*(lamY.*(lamY+Y).^( ...
    -1)).^thetY))+exp(1).^(rho.*(2+(lamX.*(lamX+X).^(-1)).^thetX)).*((-1)+rho.*((lamX.*(lamX+X).^(-1)).^thetX+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY))+exp(1).^(rho.*( ...
    1+(lamX.*(lamX+X).^(-1)).^thetX)).*(1+rho.*((-1)+(-1).*(lamX.*(lamX+X).^(-1)).^thetX+(lamY.*(lamY+Y).^(-1)).^thetY))+exp(1).^(rho.*(2+(lamY.*(lamY+Y).^(-1)) ...
    .^thetY)).*((-1)+rho.*((-1).*(lamX.*(lamX+X).^(-1)).^thetX+(lamY.*(lamY+Y).^(-1)).^thetY))+exp(1).^(rho.*(1+(lamX.*(lamX+X).^(-1)).^thetX+(lamY.*(lamY+Y).^(-1)) ...
    .^thetY)).*(1+(-1).*rho.*((-2)+(lamX.*(lamX+X).^(-1)).^thetX+(lamY.*(lamY+Y).^(-1)).^thetY))+exp(1).^(rho.*((lamX.*(lamX+X).^(-1)).^thetX+(lamY.*(lamY+Y).^(-1)) ...
    .^thetY)).*((-1)+rho.*((-1)+(lamX.*(lamX+X).^(-1)).^thetX+(lamY.*(lamY+Y).^(-1)).^thetY))+(-1).*exp(1).^rho.*(1+rho.*((-1)+(lamX.*(lamX+X).^(-1)).^thetX+(lamY.* ...
    (lamY+Y).^(-1)).^thetY))+exp(1).^(2.*rho).*(1+rho.*((lamX.*(lamX+X).^(-1)).^thetX+(lamY.*(lamY+Y).^(-1)).^thetY))));

s = [sX_l sX_t sY_l sY_t s_r];
ss = s'*s;

VarFMLE_F = inv(ss);

fprintf('Par      | LamX         | ThetX    | LamY         | ThetY    | gamma \n');
fprintf('Est      | %f | %f | %f | %f | %f\n', vertcat(exp(OptFMLE_F(1:4)), OptFMLE_F(5)));
fprintf('StEr     | %f  | %f | %f  | %f | %f\n',[sqrt( VarFMLE_F(1,1)), sqrt( VarFMLE_F(2,2)), sqrt(VarFMLE_F(3,3)), sqrt( VarFMLE_F(4,4)), sqrt( VarFMLE_F(5,5))]);
fprintf('LogL     | %f \n', -logLFMLE_F);
fprintf('Time     | %f \n', toc);

%%
tic

fprintf('==========================  FMLE Gumbel-Hougaard ============================\n');


a = log(1.453-1);     % a=alpha, where alpha is used in Frees and Valdez 98


[OptFMLE_GH, logLFMLE_GH] = fminunc(@AppLoglikelihood_FMLE_Gum, [OptQMLE; a], Options, X, Y ,d);

lamX=exp(OptFMLE_GH(1));
thetX=exp(OptFMLE_GH(2));
lamY=exp(OptFMLE_GH(3));
thetY=exp(OptFMLE_GH(4));
a = exp(OptFMLE_GH(5))+1;

% Asy var matrix calculation

%from Mathematica


sX_l = lamX.^(-1).*(lamX+X).^(-1).*((-1)+(lamX.*(lamX+X).^(-1)).^thetX).^(-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1).*((-1)+a+(((-1).*log(1+(-1).*(lamX.*( ...
    lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(a.^(-1))).^(-1).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+(( ...
    -1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(-1).*(((-1)+d).*(thetX.*X+lamX.*((-1)+(lamX.*(lamX+X).^(-1)).^thetX)).*log(1+(-1).*(lamX.*(lamX+X).^(-1)) ...
    .^thetX).*((-1)+a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(a.^(-1))).*(((-1).*log(1+(-1) ...
    .*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a)+thetX.*X.*(lamX.*(lamX+X).^(-1)).^thetX.*(((-1)+d).*(((-1).*log(1+( ...
    -1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a.*(((-1)+a).*a+2.*((-1)+a).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^( ...
    -1)).^thetY)).^a).^(a.^(-1))+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(2.*a.^(-1)))+(-1).* ...
    ((-1)+a).*((-1)+a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(a.^(-1))).*((-1).*log(1+(-1).* ...
    (lamY.*(lamY+Y).^(-1)).^thetY)).^a)+d.*((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a.*((-1)+a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+(( ...
    -1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(a.^(-1))).^2.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y) ...
    .^(-1)).^thetY)).^a).^(a.^(-1)).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a.*((-1).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).* ...
    log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(a.^(-1)).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+exp(1).^((((-1).*log(1+(-1).*(lamX.*(lamX+X) ...
    .^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(a.^(-1))).*((-1)+(lamY.*(lamY+Y).^(-1)).^thetY).*(((-1).*log(1+(-1).*(lamX.*(lamX+ ...
    X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(-1)));
sX_t=log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1).*((-1).*((-1)+d).*thetX.^(-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)+((lamX.*X.^(-1)).^thetX+(-1).*(X.^( ...
    -1).*(lamX+X)).^thetX).^(-1).*log(lamX.*(lamX+X).^(-1)).*(((-1)+d).*(X.^(-1).*(lamX+X)).^thetX.*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)+((-1)+a).*(lamX.*X.^( ...
    -1)).^thetX.*(1+(-1).*d+((-1/2)+(-1/2).*((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^((-1).*a).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^( ...
    -1))+(lamX.*X.^(-1)).^thetX.*((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*( ...
    lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(-1).*(2.*((-1)+a).*d+((-1)+a).*((-1)+d).*((-1)+a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).* ...
    (lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(a.^(-1))).^(-1)+((-1)+d).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)) ...
    .^thetY)).^a).^(a.^(-1))+(-1).*d.*(Y.^(-1).*(lamY+Y)).^thetY.*((-1)+a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y) ...
    .^(-1)).^thetY)).^a).^(a.^(-1))).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(a.^(-1)).*(( ...
    -1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a.*((Y.^(-1).*(lamY+Y)).^thetY.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*( ...
    lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(a.^(-1)).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+exp(1).^((((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX) ...
    ).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(a.^(-1))).*((-1).*(lamY.*Y.^(-1)).^thetY+(Y.^(-1).*(lamY+Y)).^thetY).*(((-1).*log(1+(-1).*(lamX.*( ...
    lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(-1))));
sY_l=lamY.^(-1).*(lamY+Y).^(-1).*((-1).*lamY+thetY.*Y)+(-1).*d.*lamY.^((-1)+thetY).*thetY.*Y.*((lamY+Y).^(-1)).^(1+thetY).*((-1)+(lamY.*(lamY+Y).^(-1)).^thetY).^(-1) ...
    .*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^((-1)+a.^(-1)).*((-1).*log(1+(-1).*(lamY.*( ...
    lamY+Y).^(-1)).^thetY)).^((-1)+a).*((-1).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(a.^( ...
    -1)).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+exp(1).^((((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y) ...
    .^(-1)).^thetY)).^a).^(a.^(-1))).*((-1)+(lamY.*(lamY+Y).^(-1)).^thetY).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+ ...
    Y).^(-1)).^thetY)).^a).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(-1).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a.*(1+(-1).*a+log(1+(-1).*( ...
    lamY.*(lamY+Y).^(-1)).^thetY))+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a.*((((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1) ...
    .*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(a.^(-1))+log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)))+(-1).*((-1)+d).*lamY.^((-1)+thetY).*thetY.*Y.*((lamY+Y).^(-1)).^( ...
    1+thetY).*((-1)+(lamY.*(lamY+Y).^(-1)).^thetY).^(-1).*((-1)+a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)) ...
    .^thetY)).^a).^(a.^(-1))).^(-1).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(-1).*log(1+(-1) ...
    .*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a.*((-1)+a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+( ...
    (-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(a.^(-1))).*((-1)+a+(-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY))+(-1).*((-1).*log(1+(-1).*(lamY.*( ...
    lamY+Y).^(-1)).^thetY)).^a.*((((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(2.*a.^(-1))+((-1)+ ...
    a).*(a+log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY))+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a) ...
    .^(a.^(-1)).*((-2)+2.*a+log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY))));
sY_t=thetY.^(-1)+log(lamY)+log((lamY+Y).^(-1))+(-1).*d.*(lamY.*(lamY+Y).^(-1)).^thetY.*((-1)+(lamY.*(lamY+Y).^(-1)).^thetY).^(-1).*log(lamY.*(lamY+Y).^(-1)).*(((-1) ...
    .*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^((-1)+a.^(-1)).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^( ...
    -1)).^thetY)).^((-1)+a).*((-1).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(a.^(-1)).*((-1) ...
    .*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+exp(1).^((((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)) ...
    .^thetY)).^a).^(a.^(-1))).*((-1)+(lamY.*(lamY+Y).^(-1)).^thetY).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1) ...
    ).^thetY)).^a).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(-1).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a.*(1+(-1).*a+log(1+(-1).*(lamY.*(lamY+ ...
    Y).^(-1)).^thetY))+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a.*((((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*( ...
    lamY+Y).^(-1)).^thetY)).^a).^(a.^(-1))+log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)))+((-1)+d).*(lamY.*(lamY+Y).^(-1)).^thetY.*((-1)+(lamY.*(lamY+Y).^(-1)) ...
    .^thetY).^(-1).*log(lamY.*(lamY+Y).^(-1)).*((-1)+a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a) ...
    .^(a.^(-1))).^(-1).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(-1).*log(1+(-1).*(lamY.*( ...
    lamY+Y).^(-1)).^thetY).^(-1).*((-1).*((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a.*((-1)+a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1) ...
    .*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(a.^(-1))).*((-1)+a+(-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY))+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^( ...
    -1)).^thetY)).^a.*((((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(2.*a.^(-1))+((-1)+a).*(a+log( ...
    1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY))+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(a.^(-1)) ...
    .*((-2)+2.*a+log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY))));
s_a=a.^(-2).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(-1).*(d.*(((-1).*log(1+(-1).*(lamX.*( ...
    lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(a.^(-1)).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a.*((-1).*((( ...
    -1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(a.^(-1)).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)) ...
    .^thetY)).^a+exp(1).^((((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(a.^(-1))).*((-1)+(lamY.*( ...
    lamY+Y).^(-1)).^thetY).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).*log(1+(-1).*(lamY.*(lamY+ ...
    Y).^(-1)).^thetY)).^(-1).*(a.*((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a.*((-1)+a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log( ...
    1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(a.^(-1))).*log((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX))+(-1).*((-1)+(((-1).*log(1+(-1).*(lamX.*(lamX+X) ...
    .^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(a.^(-1))).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1) ...
    .*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).*log(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a)+(-1).* ...
    a.*(a.*((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+(-1).*((-1)+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+ ...
    Y).^(-1)).^thetY)).^a).^(a.^(-1))).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).*log((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)))+((-1)+d).*(( ...
    -1)+a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(a.^(-1))).^(-1).*(a.*(((-1).*log(1+(-1).*( ...
    lamX.*(lamX+X).^(-1)).^thetX)).^a.*(1+(-3).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(a.^( ...
    -1))+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(2.*a.^(-1)))+a.^2.*(((-1).*log(1+(-1).*( ...
    lamX.*(lamX+X).^(-1)).^thetX)).^a+(-1).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a)+a.*((-1)+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+( ...
    (-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(a.^(-1))).*(2.*((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+(-1).*((-1).*log(1+(-1).*(lamY.*( ...
    lamY+Y).^(-1)).^thetY)).^a)).*log((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX))+(-1).*(1+a.*((-1)+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+(( ...
    -1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(a.^(-1)))+(-3).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y) ...
    .^(-1)).^thetY)).^a).^(a.^(-1))+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(2.*a.^(-1))).*(( ...
    (-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).*log(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)) ...
    .^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a)+(-1).*a.*(a.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*( ...
    lamY.*(lamY+Y).^(-1)).^thetY)).^a)+(-1).*((-1).*a.*((-1)+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)) ...
    .^thetY)).^a).^(a.^(-1))).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+(-2).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a)+a.^2.*((-1).*(( ...
    -1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a)+(1+(-3).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)) ...
    .^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(a.^(-1))+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.* ...
    (lamY+Y).^(-1)).^thetY)).^a).^(2.*a.^(-1))).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).*log((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)))));


s = [sX_l sX_t sY_l sY_t s_a];
ss = s'*s;


VarFMLE_GH = inv(ss);


fprintf('Par      | LamX         | ThetX    | LamY         | ThetY    | gamma \n');
fprintf('Est      | %f | %f | %f | %f | %f\n', vertcat(exp(OptFMLE_GH(1:4)), exp(OptFMLE_GH(5))+1));
fprintf('StEr     | %f  | %f | %f  | %f | %f\n',[sqrt( VarFMLE_GH(1,1)), sqrt( VarFMLE_GH(2,2)), sqrt(VarFMLE_GH(3,3)), sqrt( VarFMLE_GH(4,4)), sqrt( VarFMLE_GH(5,5))]);
fprintf('LogL     | %f \n', -logLFMLE_GH);
fprintf('Time     | %f \n', toc);

%%
tic
fprintf('==========================  FMLE Galambos ============================\n');


a = log(.71);     % a=delta in Hua 2017

[OptFMLE, logLFMLE_Gal, ECFMLE] = fminunc(@AppLoglikelihood_FMLE_Galambos, [OptQMLE; a], Options, X, Y ,d);

lamX=exp(OptFMLE(1));
thetX=exp(OptFMLE(2));
lamY=exp(OptFMLE(3));
thetY=exp(OptFMLE(4));
a = exp(OptFMLE(5));

% Asy var matrix calculation

%from Mathematica


sX_l =(-1).*d.*exp(1).^((((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^((-1).*a.^(-1))).* ...
    lamX.^((-1)+thetX).*thetX.*X.*((lamX+X).^(-1)).^(1+thetX).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1).*(1+(-1).*exp(1).^((((-1).*log(1+(-1).*(lamX.*(lamX+ ...
    X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^((-1).*a.^(-1))).*(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*(1+(-1).*(( ...
    (-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^((-1).*a.^(-1).*(1+a)).*((-1).*log(1+( ...
    -1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^((-1)+(-1).*a))).^(-1).*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^( ...
    -1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(1+a.^(-1)).*(1+(-1).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).* ...
    log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(1+a.^(-1)).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(1+a))+((-1).*log(1+(-1).*(lamX.*(lamX+ ...
    X).^(-1)).^thetX).^(-1)).^a.*(1+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^( ...
    -1))+a.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1))+(-1).*(((-1).*log( ...
    1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(1+a.^(-1)).*((-1).*log(1+(-1).*(lamY.*(lamY+Y) ...
    .^(-1)).^thetY)).^(1+a))).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^((-2).* ...
    a.^(-1).*(1+a)).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^((-1)+(-1).*a)+(-1).*((-1)+d).*(lamX.^(-1).*thetX+(-1).*(1+thetX).*(lamX+X).^(-1)+(-1).* ...
    lamX.^((-1)+thetX).*thetX.*X.*((lamX+X).^(-1)).^(1+thetX).*((-1)+(lamX.*(lamX+X).^(-1)).^thetX).^(-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)+(-2).* ...
    lamX.^((-1)+thetX).*thetX.*X.*((lamX+X).^(-1)).^(1+thetX).*((-1)+(lamX.*(lamX+X).^(-1)).^thetX).^(-1).*((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)) ...
    .^(1+a).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(-1)+(-1).*lamX.^((-1)+ ...
    thetX).*thetX.*X.*((lamX+X).^(-1)).^(1+thetX).*((-1)+(lamX.*(lamX+X).^(-1)).^thetX).^(-1).*((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^(1+a).*((( ...
    -1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^((-1).*a.^(-1).*(1+a))+2.*a.*lamX.^((-1) ...
    +thetX).*thetX.*X.*((lamX+X).^(-1)).^(1+thetX).*((-1)+(lamX.*(lamX+X).^(-1)).^thetX).^(-1).*((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^((-1)+a).*(((-1) ...
    .*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(-1)+(-1).*lamX.^((-1)+thetX).*thetX.*X.*((lamX+X).^( ...
    -1)).^(1+thetX).*(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1).*((log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).* ...
    log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^( ...
    -1)).^a).^(a.^(-1)).*((-1).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(1+2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+ ...
    Y).^(-1)).^thetY)).^a.*(1+a+log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY))+log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)) ...
    .^thetX)).^(2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX) ...
    .^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).*(((-1).*log(1+(-1).*(lamX.*( ...
    lamX+X).^(-1)).^thetX)).^(2.*a)+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(2.*a)+2.*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*( ...
    lamY+Y).^(-1)).^thetY)).^a)))).^(-1).*(a.*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+((-1).*log(1+(-1).*(lamX.* ...
    (lamX+X).^(-1)).^thetX).^(-1)).^a.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(( ...
    -1)+a.^(-1)).*(((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(1+2.*a)+(-1).*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1) ...
    ).^thetY)).^a.*(1+a+log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY))+(-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)) ...
    .^thetX)).^(2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX) ...
    .^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).*(((-1).*log(1+(-1).*(lamX.*( ...
    lamX+X).^(-1)).^thetX)).^(2.*a)+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(2.*a)+2.*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*( ...
    lamY+Y).^(-1)).^thetY)).^a)))+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^( ...
    -1)).*(a.*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a.*(1+a+log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY))+log(1+( ...
    -1).*(lamX.*(lamX+X).^(-1)).^thetX).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*( ...
    lamY.*(lamY+Y).^(-1)).^thetY)).^a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^( ...
    a.^(-1)).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)) ...
    .^thetY)).^(2.*a)+2.*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a))+log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*( ...
    a.*(2.*((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a)+( ...
    ((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^((-1)+a.^(-1)).*log(1+(-1).*(lamY.*( ...
    lamY+Y).^(-1)).^thetY).*(2.*a.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).*(((-1) ...
    .*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a)+(-1).*((-1).* ...
    log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)) ...
    .^thetY)).^(2.*a)+2.*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a))))));
sX_t = (-1).*d.*exp(1).^((((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^((-1).*a.^(-1))).*( ...
    lamX.*(lamX+X).^(-1)).^thetX.*log(lamX.*(lamX+X).^(-1)).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1).*(1+(-1).*exp(1).^((((-1).*log(1+(-1).*(lamX.*(lamX+X) ...
    .^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^((-1).*a.^(-1))).*(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*(1+(-1).*((( ...
    -1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^((-1).*a.^(-1).*(1+a)).*((-1).*log(1+( ...
    -1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^((-1)+(-1).*a))).^(-1).*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^( ...
    -1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(1+a.^(-1)).*(1+(-1).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).* ...
    log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(1+a.^(-1)).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(1+a))+((-1).*log(1+(-1).*(lamX.*(lamX+ ...
    X).^(-1)).^thetX).^(-1)).^a.*(1+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^( ...
    -1))+a.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1))+(-1).*(((-1).*log( ...
    1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(1+a.^(-1)).*((-1).*log(1+(-1).*(lamY.*(lamY+Y) ...
    .^(-1)).^thetY)).^(1+a))).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^((-2).* ...
    a.^(-1).*(1+a)).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^((-1)+(-1).*a)+(-1).*((-1)+d).*(thetX.^(-1)+log(lamX)+log((lamX+X).^(-1))+(-1).*(lamX.*( ...
    lamX+X).^(-1)).^thetX.*((-1)+(lamX.*(lamX+X).^(-1)).^thetX).^(-1).*log(lamX.*(lamX+X).^(-1)).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)+(-2).*(lamX.*( ...
    lamX+X).^(-1)).^thetX.*((-1)+(lamX.*(lamX+X).^(-1)).^thetX).^(-1).*log(lamX.*(lamX+X).^(-1)).*((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^(1+a).*( ...
    ((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(-1)+(-1).*(lamX.*(lamX+X).^(-1)) ...
    .^thetX.*((-1)+(lamX.*(lamX+X).^(-1)).^thetX).^(-1).*log(lamX.*(lamX+X).^(-1)).*((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^(1+a).*(((-1).*log(1+( ...
    -1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^((-1).*a.^(-1).*(1+a))+2.*a.*(lamX.*(lamX+X).^(-1)) ...
    .^thetX.*((-1)+(lamX.*(lamX+X).^(-1)).^thetX).^(-1).*log(lamX.*(lamX+X).^(-1)).*((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^((-1)+a).*(((-1).*log(1+(-1) ...
    .*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(-1)+(-1).*(lamX.*(lamX+X).^(-1)).^thetX.*(1+(-1).*(lamX.*(lamX+X) ...
    .^(-1)).^thetX).^(-1).*log(lamX.*(lamX+X).^(-1)).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1).*((log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*( ...
    lamY.*(lamY+Y).^(-1)).^thetY)).^a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^( ...
    a.^(-1)).*((-1).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(1+2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)) ...
    .^thetY)).^a.*(1+a+log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY))+log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)) ...
    .^(2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)) ...
    .^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^( ...
    -1)).^thetX)).^(2.*a)+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(2.*a)+2.*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^( ...
    -1)).^thetY)).^a)))).^(-1).*(a.*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+((-1).*log(1+(-1).*(lamX.*(lamX+X) ...
    .^(-1)).^thetX).^(-1)).^a.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^((-1)+a.^( ...
    -1)).*(((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(1+2.*a)+(-1).*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)) ...
    .^thetY)).^a.*(1+a+log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY))+(-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)) ...
    .^thetX)).^(2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX) ...
    .^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).*(((-1).*log(1+(-1).*(lamX.*( ...
    lamX+X).^(-1)).^thetX)).^(2.*a)+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(2.*a)+2.*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*( ...
    lamY+Y).^(-1)).^thetY)).^a)))+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^( ...
    -1)).*(a.*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a.*(1+a+log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY))+log(1+( ...
    -1).*(lamX.*(lamX+X).^(-1)).^thetX).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*( ...
    lamY.*(lamY+Y).^(-1)).^thetY)).^a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^( ...
    a.^(-1)).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)) ...
    .^thetY)).^(2.*a)+2.*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a))+log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*( ...
    a.*(2.*((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a)+( ...
    ((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^((-1)+a.^(-1)).*log(1+(-1).*(lamY.*( ...
    lamY+Y).^(-1)).^thetY).*(2.*a.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).*(((-1) ...
    .*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a)+(-1).*((-1).* ...
    log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)) ...
    .^thetY)).^(2.*a)+2.*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a))))));
sY_l = lamY.^(-1).*(lamY+Y).^(-1).*((-1).*lamY+thetY.*Y)+d.*exp(1).^((((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^( ...
    -1)).^thetY).^(-1)).^a).^((-1).*a.^(-1))).*lamY.^((-1)+thetY).*thetY.*((-1)+(lamX.*(lamX+X).^(-1)).^thetX).*Y.*((lamY+Y).^(-1)).^(1+thetY).*((-1)+(lamY.*(lamY+ ...
    Y).^(-1)).^thetY).^(-1).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^((-1).*a.^( ...
    -1).*(1+a)).*(exp(1).^((((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^((-1).*a.^(-1) ...
    )).*((-1)+(lamX.*(lamX+X).^(-1)).^thetX)+(-1).*(1+exp(1).^((((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1) ...
    ).^thetY).^(-1)).^a).^((-1).*a.^(-1))).*((-1)+(lamX.*(lamX+X).^(-1)).^thetX)).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*( ...
    lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(1+a.^(-1)).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(1+a)).^(-1).*((-1).*((-1).*log(1+(-1).*(lamX.*(lamX+ ...
    X).^(-1)).^thetX).^(-1)).^a.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1) ...
    )+(-1).*a.*((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*( ...
    lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1))+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a+(-1).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)) ...
    .^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(1+a.^(-1)).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a.*((-1) ...
    .*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(1+a)).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)+(-1).*((-1)+d).*lamY.^((-1)+thetY).*thetY.*Y.*((lamY+Y) ...
    .^(-1)).^(1+thetY).*((-1)+(lamY.*(lamY+Y).^(-1)).^thetY).^(-1).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y) ...
    .^(-1)).^thetY).^(-1)).^a).^((-1).*a.^(-1).*(1+a)).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)) ...
    .^a).^(-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1).*((1+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+ ...
    Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1))+a.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)) ...
    .^a).^(a.^(-1))).*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX) ...
    .^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).*(((-1).*log(1+(-1).*(lamY.*( ...
    lamY+Y).^(-1)).^thetY)).^(2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a)+log(1+(-1).*(lamX.*(lamX+X).^(-1)) ...
    .^thetX).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*(((-1).*log(1+( ...
    -1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+(((-1).*log(1+(-1).*( ...
    lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).*((( ...
    -1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(2.*a)+2.*(log(1+(-1).*(lamX.*(lamX+X).^(-1)) ...
    .^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a))).^(-1).*((a.^2.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*( ...
    lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1).*(2+a)).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+(-1).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^( ...
    -1)).^thetY)).^a)+((-1).*((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+ ...
    (-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1))+(-1).*((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a.*(((-1).*log(1+(-1).*(lamX.*(lamX+ ...
    X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(2.*a.^(-1))+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)) ...
    .^a+2.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*((-1).*log(1+(-1).* ...
    (lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a)+a.*((( ...
    -1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*(((-1).*log(1+(-1).*(lamX.*( ...
    lamX+X).^(-1)).^thetX).^(-1)).^a.*((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+2.*((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a.*((-1).*log(1+( ...
    -1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a+((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)) ...
    .^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a+(-1).*((-1).*log(1+(-1) ...
    .*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a.*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+(-2).*((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)) ...
    .^a.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*((-1).*log(1+(-1).*( ...
    lamY.*(lamY+Y).^(-1)).^thetY)).^a+(-1).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)) ...
    .^a).^(a.^(-1)).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a.*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a)).*(log(1+(-1).*(lamX.*( ...
    lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*( ...
    lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).*((1+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1) ...
    .*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1))).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y) ...
    .^(-1)).^thetY)).^a).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a.*(((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(2.*a)+(log(1+(-1).*( ...
    lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a)+a.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1) ...
    .*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(1+a.^(-1)).*(2.*((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a.*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)) ...
    .^thetY)).^(2.*a)+((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a.*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY) ...
    ).^a+(-1).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a.*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a))+ ...
    log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1) ...
    ).^a).^(a.^(-1)).*(((-1).*((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log( ...
    1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1))+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).*(((-1).*log(1+(-1).*(lamX.*(lamX+X) ...
    .^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+(log(1+(-1).*(lamX.*( ...
    lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a)+(-1).*a.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1) ...
    .*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(1+a.^(-1)).*(2.*((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^( ...
    -1)).^thetY)).^a+(-1).*((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a.*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)) ...
    .^thetY)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a.*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a) ...
    +(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*log(1+(-1).*(lamY.*(lamY+ ...
    Y).^(-1)).^thetY).*((-2).*a.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(1+a.^( ...
    -1)).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+(-1).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).*(((-1).*log(1+(-1).*(lamX.*(lamX+X) ...
    .^(-1)).^thetX)).^a.*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+(-1).*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)) ...
    .^thetY)).^a)+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).*((-1).*log(1+(-1).*(lamY.*(lamY+Y) ...
    .^(-1)).^thetY).^(-1)).^a.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(2.*a)+2.*(log(1+(-1) ...
    .*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a))));
sY_t = thetY.^(-1)+log(lamY)+log((lamY+Y).^(-1))+d.*exp(1).^((((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)) ...
    .^thetY).^(-1)).^a).^((-1).*a.^(-1))).*((-1)+(lamX.*(lamX+X).^(-1)).^thetX).*(lamY.*(lamY+Y).^(-1)).^thetY.*((-1)+(lamY.*(lamY+Y).^(-1)).^thetY).^(-1).*log( ...
    lamY.*(lamY+Y).^(-1)).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^((-1).*a.^(-1) ...
    .*(1+a)).*(exp(1).^((((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^((-1).*a.^(-1))) ...
    .*((-1)+(lamX.*(lamX+X).^(-1)).^thetX)+(-1).*(1+exp(1).^((((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)) ...
    .^thetY).^(-1)).^a).^((-1).*a.^(-1))).*((-1)+(lamX.*(lamX+X).^(-1)).^thetX)).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*( ...
    lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(1+a.^(-1)).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(1+a)).^(-1).*((-1).*((-1).*log(1+(-1).*(lamX.*(lamX+ ...
    X).^(-1)).^thetX).^(-1)).^a.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1) ...
    )+(-1).*a.*((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*( ...
    lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1))+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a+(-1).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)) ...
    .^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(1+a.^(-1)).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a.*((-1) ...
    .*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(1+a)).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)+(lamY.*(lamY+Y).^(-1)).^thetY.*((-1)+(lamY.*(lamY+Y).^( ...
    -1)).^thetY).^(-1).*log(lamY.*(lamY+Y).^(-1)).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1).*((-1)+d+2.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX) ...
    .^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(-1).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a+(-2).*d.*(((-1).*log( ...
    1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(-1).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)) ...
    .^thetY).^(-1)).^a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^((-1).*a.^(-1).*( ...
    1+a)).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a+(-1).*d.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*( ...
    lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^((-1).*a.^(-1).*(1+a)).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a+(-2).*a.*(((-1).*log(1+(-1).*( ...
    lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(-1).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+2.*a.*d.*( ...
    ((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(-1).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)) ...
    .^thetY)).^a+(-1).*((log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)) ...
    .^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*((-1).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(1+2.*a)+ ...
    (log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a.*(1+a+log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY))+log(1+(-1).*( ...
    lamX.*(lamX+X).^(-1)).^thetX).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*( ...
    lamY+Y).^(-1)).^thetY)).^a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)) ...
    .*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^( ...
    2.*a)+2.*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a)))).^(-1).*((-1).*a.*(log(1+(-1).*(lamX.*(lamX+X).^(-1)) ...
    .^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)) ...
    .^thetY).^(-1)).^a).^((-1)+a.^(-1)).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a.*((-1).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(1+ ...
    2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a.*(1+a+log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY))+log(1+(-1).* ...
    (lamX.*(lamX+X).^(-1)).^thetX).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*( ...
    lamY+Y).^(-1)).^thetY)).^a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)) ...
    .*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^( ...
    2.*a)+2.*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a)))+(-1).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX) ...
    .^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*((-1).*(1+2.*a).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(1+2.* ...
    a)+log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+a.*(log(1+(-1).*( ...
    lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a.*(1+a+log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY))+log(1+(-1).*(lamX.*(lamX+X).^( ...
    -1)).^thetX).*(a.*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX) ...
    .^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^((-1)+a.^(-1)).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).*(2.*a.*(((-1).*log(1+(-1).* ...
    (lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).*(((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(2.* ...
    a)+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a)+((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a.*((( ...
    -1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(2.*a)+2.*(log(1+(-1).*(lamX.*(lamX+X).^(-1)) ...
    .^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a)))))+d.*((log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+(( ...
    (-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*((-1).*((-1).*log(1+(-1).*( ...
    lamY.*(lamY+Y).^(-1)).^thetY)).^(1+2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a.*(1+a+log(1+(-1).*(lamY.*( ...
    lamY+Y).^(-1)).^thetY))+log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^( ...
    -1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^( ...
    -1)).^thetY).^(-1)).^a).^(a.^(-1)).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+((-1).*log(1+(-1).*( ...
    lamY.*(lamY+Y).^(-1)).^thetY)).^(2.*a)+2.*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a)))).^(-1).*((-1).*a.*(log( ...
    1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log( ...
    1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^((-1)+a.^(-1)).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a.*((-1).*((-1).*log(1+(-1).*( ...
    lamY.*(lamY+Y).^(-1)).^thetY)).^(1+2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a.*(1+a+log(1+(-1).*(lamY.*( ...
    lamY+Y).^(-1)).^thetY))+log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^( ...
    -1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^( ...
    -1)).^thetY).^(-1)).^a).^(a.^(-1)).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+((-1).*log(1+(-1).*( ...
    lamY.*(lamY+Y).^(-1)).^thetY)).^(2.*a)+2.*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a)))+(-1).*(((-1).*log(1+( ...
    -1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*((-1).*(1+2.*a).*((-1).*log(1+(-1).*( ...
    lamY.*(lamY+Y).^(-1)).^thetY)).^(1+2.*a)+log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^( ...
    -1)).^thetY)).^a+a.*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a.*(1+a+log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY) ...
    )+log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*(a.*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+(((-1).*log(1+(-1) ...
    .*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^((-1)+a.^(-1)).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)) ...
    .^thetY).*(2.*a.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).*(((-1).*log(1+(-1).* ...
    (lamY.*(lamY+Y).^(-1)).^thetY)).^(2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a)+((-1).*log(1+(-1).*(lamX.*( ...
    lamX+X).^(-1)).^thetX).^(-1)).^a.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(2.*a)+2.*( ...
    log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a))))));
s_a = a.^(-2).*d.*exp(1).^((((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^((-1).*a.^(-1))) ...
    .*(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*(1+(-1).*exp(1).^((((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^( ...
    -1)).^thetY).^(-1)).^a).^((-1).*a.^(-1))).*(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*(1+(-1).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1) ...
    .*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^((-1).*a.^(-1).*(1+a)).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^((-1)+(-1).*a))).^(-1).*((( ...
    -1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^((-2)+(-1).*a.^(-1)).*log(1+(-1).*( ...
    lamY.*(lamY+Y).^(-1)).^thetY).^(-1).*((-1).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1) ...
    ).^a).*((((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^((-1).*a.^(-1).*(1+a)).*((-1) ...
    .*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^((-1).*a)+log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).*((((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)) ...
    .^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).*log(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*( ...
    lamY+Y).^(-1)).^thetY).^(-1)).^a)+(-1).*a.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a.*log((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^( ...
    -1))+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a.*log((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1))))+((-1).*log(1+(-1).*(lamY.*(lamY+ ...
    Y).^(-1)).^thetY)).^((-1).*a).*((-1).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a) ...
    .*log(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a)+a.*(1+a).*(((-1).*log(1+(-1).*( ...
    lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a.*log((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1))+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)) ...
    .^a.*log((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1))))+a.^2.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.* ...
    (lamY+Y).^(-1)).^thetY).^(-1)).^a).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^((-1).*a).*log((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)))+(-1).* ...
    ((-1)+d).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^((-1).*a.^(-1)).*(((-1).* ...
    log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).^(-1).*((log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log( ...
    1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)) ...
    .^a).^(a.^(-1)).*((-1).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(1+2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^( ...
    -1)).^thetY)).^a.*(1+a+log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY))+log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)) ...
    .^thetX)).^(2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX) ...
    .^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).*(((-1).*log(1+(-1).*(lamX.*( ...
    lamX+X).^(-1)).^thetX)).^(2.*a)+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(2.*a)+2.*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*( ...
    lamY+Y).^(-1)).^thetY)).^a)))).^(-1).*(a.^(-2).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).*( ...
    (log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).* ...
    log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*((-1).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(1+2.*a)+(log(1+(-1).*(lamX.*(lamX+ ...
    X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a.*(1+a+log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY))+log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).* ...
    (((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+(((-1).* ...
    log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)) ...
    .^thetY).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(2.*a)+2.*(log(1+(-1).*(lamX.*(lamX+X) ...
    .^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a)))).*(log(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.* ...
    (lamY+Y).^(-1)).^thetY).^(-1)).^a)+(-1).*a.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1) ...
    ).^a).^(-1).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a.*log((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1))+((-1).*log(1+(-1).*( ...
    lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a.*log((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1))))+2.*a.^(-2).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)) ...
    .^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a+((-1).*log(1+ ...
    (-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).*((log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+(((-1).*log(1+(-1).*( ...
    lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*((-1).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1) ...
    ).^thetY)).^(1+2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a.*(1+a+log(1+(-1).*(lamY.*(lamY+Y).^(-1)) ...
    .^thetY))+log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).* ...
    log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^( ...
    -1)).^a).^(a.^(-1)).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+((-1).*log(1+(-1).*(lamY.*(lamY+Y) ...
    .^(-1)).^thetY)).^(2.*a)+2.*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a)))).*(log(((-1).*log(1+(-1).*(lamX.*( ...
    lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a)+(-1).*a.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)) ...
    .^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(-1).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a.*log((-1).*log(1+(-1).*( ...
    lamX.*(lamX+X).^(-1)).^thetX).^(-1))+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a.*log((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1))))+ ...
    (-2).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*((log(1+(-1).*( ...
    lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*( ...
    lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*((-1).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(1+2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^(-1)) ...
    .^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a.*(1+a+log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY))+log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*(((-1).* ...
    log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+(((-1).*log(1+( ...
    -1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)) ...
    .^thetY).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(2.*a)+2.*(log(1+(-1).*(lamX.*(lamX+X) ...
    .^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a)))).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^a.*log((-1).*log(1+(-1).*(lamX.*(lamX+ ...
    X).^(-1)).^thetX))+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a.*log((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)))+(((-1).*log(1+(-1).*(lamX.*( ...
    lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)) ...
    .^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a).*(a.^(-2).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*( ...
    lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*((-1).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(1+2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).* ...
    log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a.*(1+a+log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY))+log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*(((-1).*log(1+(-1) ...
    .*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a+(((-1).*log(1+(-1).*( ...
    lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).*((( ...
    -1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a)+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(2.*a)+2.*(log(1+(-1).*(lamX.*(lamX+X).^(-1)) ...
    .^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a))).*((-1).*log(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*( ...
    lamY+Y).^(-1)).^thetY).^(-1)).^a)+a.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a) ...
    .^(-1).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a.*log((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1))+((-1).*log(1+(-1).*(lamY.*( ...
    lamY+Y).^(-1)).^thetY).^(-1)).^a.*log((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1))))+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.* ...
    (lamY+Y).^(-1)).^thetY)).^a.*log(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY))+(((-1).*log(1+(-1).*(lamX.*(lamX+X).^( ...
    -1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*((log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*( ...
    lamY.*(lamY+Y).^(-1)).^thetY)).^a+(-2).*((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(1+2.*a).*log((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY))+( ...
    log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a.*(1+a+log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).*log(log(1+(-1).*( ...
    lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY))+log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*(2.*((-1).*log(1+(-1).*(lamX.*(lamX+X).^( ...
    -1)).^thetX)).^(2.*a).*log((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX))+a.^(-2).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+ ...
    (-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^( ...
    2.*a)+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(2.*a)+2.*(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a) ...
    .*((-1).*log(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a)+a.*(((-1).*log(1+(-1).*( ...
    lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a).^(-1).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX) ...
    .^(-1)).^a.*log((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1))+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).^(-1)).^a.*log((-1).*log(1+(-1).*( ...
    lamY.*(lamY+Y).^(-1)).^thetY).^(-1))))+(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a.*log(log(1+(-1).*(lamX.*( ...
    lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY))+2.*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).^(-1)).^a+((-1).*log(1+(-1).*(lamY.*( ...
    lamY+Y).^(-1)).^thetY).^(-1)).^a).^(a.^(-1)).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY).*(((-1).*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX)).^(2.*a).*log((-1) ...
    .*log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX))+((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^(2.*a).*log((-1).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY))+ ...
    (log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.*(lamY+Y).^(-1)).^thetY)).^a.*log(log(1+(-1).*(lamX.*(lamX+X).^(-1)).^thetX).*log(1+(-1).*(lamY.* ...
    (lamY+Y).^(-1)).^thetY)))))));

s = [sX_l sX_t sY_l sY_t s_a];
ss = s'*s;

VarFMLE1 = inv(ss);

fprintf('Par      | LamX         | ThetX    | LamY         | ThetY    | gamma \n');
fprintf('Est      | %f | %f | %f | %f | %f \n', vertcat(exp(OptFMLE(1:4)), exp(OptFMLE(5))));
fprintf('StEr     | %f  | %f | %f  | %f | %f \n',[sqrt( VarFMLE1(1,1)), sqrt( VarFMLE1(2,2)), sqrt(VarFMLE1(3,3)), sqrt( VarFMLE1(4,4)), sqrt( VarFMLE1(5,5))]);
fprintf('LogL     | %f \n', -logLFMLE_Gal);
fprintf('Time     | %f \n', toc);


%% Sieve MLE: minimize the negative of log-likelihood
tic

% Optimal number of sieve elements in one dimension, total is k*k 
k=6;

fprintf('==========================  SMLE ============================\n');

nchoose=zeros(k,1);

for j = 1:k
    nchoose(j)=nchoosek(k-1,j-1);
end

%initial values from QMLE

lamX=exp(OptQMLE(1));
thetX=exp(OptQMLE(2));
lamY=exp(OptQMLE(3));
thetY=exp(OptQMLE(4));


U = 1 - (1+X/lamX).^(-thetX);   % Pareto CDF
V = 1 - (1+Y/lamY).^(-thetY);



% for simplicity use only nontruncated data for better accuracy of the initial estimate
% In=zeros(k,k); %emprical histogram

count=1/N;

In=zeros(k,k);

for l = 1:N

    i=floor(U(l)*k)+1;

    j=floor(V(l)*k)+1;
    In(i,j) = In(i,j) + count;
end

In(In==0)=eps;

Init=[OptQMLE; log(reshape(In,k*k,1))];

[OptI,logLSMLE]=fminunc(@AppLoglikelihood_SMLE_Bernstein, Init, Options, X, Y, d, k, nchoose);

fprintf('Par      | LamX         | ThetX    | LamY         | ThetY    \n');
fprintf('Est      | %f | %f | %f | %f\n', exp(OptI(1:4)));


%Estimated parameters
lamX=exp(OptI(1));
thetX=exp(OptI(2));
lamY=exp(OptI(3));
thetY=exp(OptI(4));

temp=exp(OptI(5:end));
temp=temp/sum(temp);
I=reshape(temp,k,k);


rest=1/k;
penalty=sum((sum(I,1)-rest).^2+(sum(I,2)'-rest).^2);

const=1e6;
logLSMLE=-logLSMLE+const*penalty; %logL correction for penalty, typically negligible relative to the value of logL

%estimate variance

%analytic scores first

sY_l = (-lamY+thetY.*Y)./(lamY.*(lamY+Y));
sY_t = 1/thetY + log(lamY./(lamY + Y));

dlfX_dlamX=(-lamX+thetX.*X)./(lamX.*(lamX+X));
dlfX_dthetX=1/thetX + log(lamX./(lamX + X));

dlfY_dlamY=(-lamY+thetY.*Y)./(lamY.*(lamY+Y));
dlfY_dthetY=1/thetY + log(lamY./(lamY + Y));

dFX_dlamX=-((thetX.*X.*(lamX./(lamX+X)).^(-1+thetX))./(lamX+X).^2);
dFX_dthetX=-(lamX./(lamX+X)).^thetX.*log(lamX./(lamX+X));

dFY_dlamY=-((thetY.*Y.*(lamY./(lamY+Y)).^(-1+thetY))./(lamY+Y).^2);
dFY_dthetY=-(lamY./(lamY+Y)).^thetY.*log(lamY./(lamY+Y));

%copula-based scores

c=zeros(N,1);
C2=zeros(N,1);
dcdu=zeros(N,1);
dcdv=zeros(N,1);
dC2dv=zeros(N,1);

prod1U=ones(k,1);
prod1V=ones(k,1);

U = 1 - (1+X/lamX).^(-thetX);   % Pareto CDF
V = 1 - (1+Y/lamY).^(-thetY);


for l=1:N

    u=U(l);
    v=V(l);


    dcdui=0;
    dcdvi=0;

    dC2dvi=0;

    sieve_sum=0;
    C2_sum=0;

    prodU=1;

    for i=2:k
        prod1U(i)=prod1U(i-1)*(1-u);
        prod1V(i)=prod1V(i-1)*(1-v);
    end

    for i = 1:k
        prodV=1;

        IntU=betainc(u,i,k-i+1);

        for j = 1:k
            temp=k*I(i,j)*nchoose(j)*prodV*prod1V(k-j+1);
            C2_sum=C2_sum+IntU*temp;
            dC2dvi=dC2dvi+IntU*temp*((j-1)/v-(k-j)/(1-v));

            temp=temp*k*nchoose(i)*prodU*prod1U(k-i+1);
            dcdui=dcdui+((i-1)/u-(k-i)/(1-u))*temp;
            dcdvi=dcdvi+((j-1)/v-(k-j)/(1-v))*temp;
            sieve_sum=sieve_sum+temp;

            prodV=prodV*v;
        end
        prodU=prodU*u;
    end

    c(l)=sieve_sum;
    C2(l)=C2_sum;
    dcdu(l) =dcdui;
    dcdv(l) =dcdvi;

    dC2dv(l)=dC2dvi;

end


dC2du=c; %easy to derive

dc_dlamX =dcdu.*dFX_dlamX;
dc_dthetX=dcdu.*dFX_dthetX;

dc_dlamY =dcdv.*dFY_dlamY;
dc_dthetY=dcdv.*dFY_dthetY;

dC2_dlamX =dC2du.*dFX_dlamX;
dC2_dthetX=dC2du.*dFX_dthetX;

dC2_dlamY =dC2dv.*dFY_dlamY;
dC2_dthetY=dC2dv.*dFY_dthetY;

%Sieve var

score_lamX= (1-d).*(dlfX_dlamX +dc_dlamX ./c)+d.*(-1./(1-C2).*(dC2_dlamX));
score_thetX=(1-d).*(dlfX_dthetX+dc_dthetX./c)+d.*(-1./(1-C2).*(dC2_dthetX));
score_lamY= dlfY_dlamY +(1-d).*(dc_dlamY ./c)+d.*(-1./(1-C2).*(dC2_dlamY));
score_thetY=dlfY_dthetY+(1-d).*(dc_dthetY./c)+d.*(-1./(1-C2).*(dC2_dthetY));


%bivariate cosine sieve to estimate g* term in sieve-based score
k=3;

Basis  = formCosBasis_var1(U,V,k);

Z=Basis.*repmat((1-d)./c,1,k*k);
ZZ=-(Z'*Z);


P=score_lamX;
OptI=ZZ\(Z'*P);
g_lamX = Basis * OptI;

P=score_thetX;
OptI=ZZ\(Z'*P);
g_thetX = Basis * OptI;

P=score_lamY;
OptI=ZZ\(Z'*P);
g_lamY = Basis * OptI;

P=score_thetY;
OptI=ZZ\(Z'*P);
g_thetY = Basis * OptI;


score_lamX=score_lamX+g_lamX.*(1-d)./c;
score_thetX=score_thetX+g_thetX.*(1-d)./c;
score_lamY=score_lamY+g_lamY.*(1-d)./c;
score_thetY=score_thetY+g_thetY.*(1-d)./c;

s=[score_lamX score_thetX score_lamY score_thetY];

Ismle=s'*s;
VarSMLE=inv(Ismle);

fprintf('StEr     | %f  | %f | %f  | %f\n', [sqrt( VarSMLE(1,1)), sqrt( VarSMLE(2,2)), sqrt(VarSMLE(3,3)), sqrt(VarSMLE(4,4))]);
fprintf('LogL     | %f \n', logLSMLE);
fprintf('Time     | %f \n', toc);









