#time it
start_time = Sys.time();

#load data
LOSSDATA <- read.delim("C:/Users/z3195975/OneDrive - UNSW/My Documents/Research/SieveCopula/code/Application/LOSSDATA.txt")

library(CopulaOne)
library(numDeriv)
library(ucminf)

#negative Log Likelihood for optimization (with log-transformed params to ensure they are positive)
nlogL <- function(Coefs, X, Y, d)
{
  
  lX = exp(Coefs[1]);
  tX = exp(Coefs[2]);
  lY = exp(Coefs[3]);
  tY = exp(Coefs[4]); 
  alpha = exp(Coefs[5]);
  beta = exp(Coefs[6]);
  
  #Pareto log-likelihood
  
  logLX=log(tX)+tX*log(lX)-log(lX+X)*(tX+1);   
  logLY=log(tY)+tY*log(lY)-log(lY+Y)*(tY+1);
  
  #Pareto CDF
  
  F1 = 1 - ((lX+X)/lX)^(-tX);
  F2 = 1 - ((lY+Y)/lY)^(-tY); 
  
  #GGEE copula
  
  logLc=log(dGGEE_COP(F1,F2,alpha,beta));
  
  C2=d;
  
  for(i in 1:length(C2)){
      if(d[i]==1) C2[i]=C2GGEE_COP(F1[i],F2[i],alpha,beta);
  }
  
  logL=(1-d)*(logLX+logLY+logLc)+d*(logLY+log(1-C2));
  
  
  sumlogL=sum(logL)
  
  return(-sumlogL)
}  

#Log Likelihood for computing numerical gradient and Hessian at the optimal values
logL <- function(Coefs, X, Y, d)
{
  
  lX = Coefs[1];
  tX = Coefs[2];
  lY = Coefs[3];
  tY = Coefs[4]; 
  alpha = Coefs[5];
  beta = Coefs[6];
  
  #Pareto log-likelihood
  
  logLX=log(tX)+tX*log(lX)-log(lX+X)*(tX+1);   
  logLY=log(tY)+tY*log(lY)-log(lY+Y)*(tY+1);
  
  #Pareto CDF
  
  F1 = 1 - ((lX+X)/lX)^(-tX);
  F2 = 1 - ((lY+Y)/lY)^(-tY); 
  
  #GGEE copula
  
  logLc=log(dGGEE_COP(F1,F2,alpha,beta));
  
  C2=d;
  
  for(i in 1:length(C2)){
    if(d[i]==1) C2[i]=C2GGEE_COP(F1[i],F2[i],alpha,beta);
  }
  
  logL=(1-d)*(logLX+logLY+logLc)+d*(logLY+log(1-C2));
  
  return(sum(logL))
}  


X=LOSSDATA$LOSS;
Y=LOSSDATA$ALAE;
d=LOSSDATA$CENSOR;

#starting values from QML for marginals and previously known optimal values for copula
Init=log(c(14043,1.13,15133,2.22,3.8,0.7)); 

p<-optim(Init,nlogL,X=X,Y=Y,d=d,control=list(trace=0))

optpar=exp(p$par)
optlogL=-p$value

s=matrix(0,nrow=length(d),ncol=length(optpar))

#score for each observations
for(i in 1:length(d)){
  s[i,]=grad(logL,optpar,X=X[i],Y=Y[i],d=d[i])
}

#Fisher information matrix
I=t(s)%*%s;
invI=solve(I);
SE=sqrt(diag(invI));
  

end_time = Sys.time();
run_time = end_time - start_time;

print(optpar)
print(SE)
print(optlogL)
print(run_time)
