function logl = QMLELogLikGaussianRetVolVolume(parameters,sample)
    
    % parameters(1) - parameters(3) - Returns mu, sigma, nu
    % parameters(4) - parameters(6) - Returns mu, sigma, nu
    % parameters(7) - parameters(8) - Volatility a,b
    % parameters(9) - parameter(11) - upper triangular part of the
    % correlation matrix (reshaped)
    
    vcv = [1 parameters(9) parameters(10);...
        parameters(9) 1 parameters(11);...
        parameters(10) parameters(11) 1];
    
    vcv = corrcov(vcv*vcv.');
    
    first_t_dist = makedist('tLocationScale','mu',parameters(1),'sigma',parameters(2),'nu',parameters(3));
    second_t_dist = makedist('tLocationScale','mu',parameters(4),'sigma',parameters(5),'nu',parameters(6));
    third_t_dist = makedist('Beta','a',parameters(7),'b',parameters(8));
    
    % log-likilihood contribution from marginal models
    
    marginal_models_log_lik = sum(log(pdf(first_t_dist,sample(:,1))))+...
        sum(log(pdf(second_t_dist,sample(:,2)))) + ...
        sum(log(pdf(third_t_dist,sample(:,3))));

    % log-likelihood contribution from copula density
    
    u = cdf(first_t_dist,sample(:,1));
    v = cdf(second_t_dist,sample(:,2)); 
    z = cdf(third_t_dist,sample(:,3));
    
    U = [u v z];
    
    cl = copulapdf('Gaussian',U,vcv);
    
    copula_log_lik = sum(log(cl));
    
    logl = -(marginal_models_log_lik+copula_log_lik);

end