function logl = sieveLogLikRetVolVolume(parameters,sample,JN)
    
    % parameters(1) - parameters(3) - Returns mu, sigma, nu
    % parameters(4) - parameters(6) - Volume changes mu, sigma, nu
    % parameters(7) - parameter(8) - Volatility a, b
    % parameters(9:end) - parameters(NJ^3) - Sieve parameters(JNxJNxJN total)
    
    first_t_dist = makedist('tLocationScale','mu',parameters(1),'sigma',parameters(2),'nu',parameters(3));
    second_t_dist = makedist('tLocationScale','mu',parameters(4),'sigma',parameters(5),'nu',parameters(6));
    vol_dist = makedist('Beta','a',parameters(7),'b',parameters(8));
    
    % log-likilihood contribution from marginal models
    
    marginal_models_log_lik = sum(log(pdf(first_t_dist,sample(:,1))))+...
        sum(log(pdf(second_t_dist,sample(:,2))))+...
        sum(log(pdf(vol_dist,sample(:,3))));

    % log-likelihood contribution from copula density
    
    u = cdf(first_t_dist,sample(:,1));
    v = cdf(second_t_dist,sample(:,2)); 
    z = cdf(vol_dist,sample(:,3));
    
    cl = zeros(size(sample,1),1);
    
    for i=1:size(sample,1) 
        cl(i) = c_JN_three_variables([u(i) v(i) z(i)],JN,parameters(9:end));      
    end
    
    copula_log_lik = sum(log(cl));
    
%     disp(strcat('Copula contribution:',num2str(copula_log_lik)));
    
    logl = -(marginal_models_log_lik+copula_log_lik);

end