function [betaX, betaY, BC, logLSMLE, BIC, AIC] = Estimate_SMLE_Bernstein(X, Y, k)



muX=mean(X);
muY=mean(Y);

U=expcdf(X,muX);
V=expcdf(Y,muY);

n=length(U);


In=zeros(k,k); %emprical histogram

count=1/n;
for l = 1:n

    i=floor(U(l)*k)+1;
    j=floor(V(l)*k)+1;

    In(i,j) = In(i,j) + count;
end

%constant to form polynomials faster
nchoose=zeros(k,1);

for j = 1:k
    nchoose(j)=nchoosek(k-1,j-1);
end


nchoose=zeros(k,1);

for j = 1:k
    nchoose(j)=nchoosek(k-1,j-1);
end

In(In==0)=eps;

sumIntot=sum(In,'all'); %is 1 in theory but when we correct for 0s as above can be different

%Unit simplex inverse transform as in
%https://mc-stan.org/docs/reference-manual/simplex-transform.html

Incoef=In(:);
trans=Incoef(1:end-1);

sumIncoef=Incoef(1);
for i=2:k*k-1
    trans(i)=trans(i)/(sumIntot-sumIncoef);
    sumIncoef=sumIncoef+Incoef(i);
end

trans=trans./(1-trans);

Init=log([muX; muY; trans]);
Options = optimset('MaxIter', 1e6, 'MaxFunEvals', 1e6,  'Display', 'off');

[OptI,nlogLSMLE]=fminunc(@(params) Loglikelihood_SMLE_Bernstein_transf(params,X, Y, k, nchoose), Init,Options);

Icoef=1./(1+exp(-OptI(3:end)));

sumIcoef=Icoef(1);
for i=2:k*k-1
    Icoef(i)=(1-sumIcoef)*Icoef(i);
    sumIcoef=sumIcoef+Icoef(i);
end

BC=reshape([Icoef; 1-sumIcoef],k,k);

betaX = exp(OptI(1));
betaY = exp(OptI(2));

rest=1/k;
penalty=sum((sum(BC,1)-rest).^2+(sum(BC,2)'-rest).^2);

const=1e4; %large constant
logLSMLE=-nlogLSMLE+const*penalty;

npar=k*k-2*k+1+2; %number of free params copula part + 2 pars of the marginals

BIC=-2*logLSMLE+npar*log(n);
AIC=-2*logLSMLE+2*npar;

end

