%matlabpool(8);

truealpha=0.05; %dependence parameter
muX=.5;      %marginal parameter
muY=1;
seed=1;
N=1e9;      %sample size


[U, V]=plackett_rnd(truealpha,N,seed);

%pseudo true value of copula parameter
paramhat = copulafit('Clayton',[1-U V]);
alpha=paramhat;


X = expinv(U,muX);
Y = expinv(V,muY);


dlXdmuX=zeros(N,1);
dlYdmuY=zeros(N,1);
dcdmuX=zeros(N,1);
dcdmuY=zeros(N,1);

c=zeros(N,1);
dcdalpha=zeros(N,1);

dlXdmuX2=zeros(N,1);
dlYdmuY2=zeros(N,1);


for i=1:N



    u=1-U(i); %rotated Clayton
    v=V(i);
    x=X(i);
    y=Y(i);

    dlXdmuX(i)=(x-muX)/(muX^2);
    dlYdmuY(i)=(y-muY)/(muY^2);

    dFdmuX=-x*exp(-x/muX)/(muX^2);
    dFdmuY=-y*exp(-y/muY)/(muY^2);

    %rotated Clayton
    %use chain rule here dc/d(1-u)=-dc/du

    dcdu=((1+alpha).*u.^((-2)+alpha).*v.^((-1)+alpha).*((-1)+u.^((-1) ...
        .*alpha)+v.^((-1).*alpha)).^((-1).*alpha.^(-1)).*((-1).*v.^alpha+ ...
        u.^alpha.*((-1)+v.^alpha)).^(-3).*(alpha.*v.^alpha+(1+alpha).* ...
        u.^alpha.*((-1)+v.^alpha)));

    dcdv=(-1).*(1+alpha).*u.^((-1)+alpha).*v.^(( ...
        -2)+alpha).*((-1)+u.^((-1).*alpha)+v.^((-1).*alpha)).^((-1).* ...
        alpha.^(-1)).*((-1).*v.^alpha+u.^alpha.*((-1)+v.^alpha)).^(-3).*(( ...
        (-1)+u.^alpha).*v.^alpha+alpha.*((-1).*v.^alpha+u.^alpha.*(1+ ...
        v.^alpha)));


    dcdmuX(i)=dcdu*dFdmuX;
    dcdmuY(i)=dcdv*dFdmuY;

    c(i)=copulapdf('Clayton',[u,v],alpha);

    dcdalpha(i)=alpha.^(-2).*u.^((-1)+alpha).*v.^((-1)+alpha).*((-1)+ ...
        u.^((-1).*alpha)+v.^((-1).*alpha)).^((-1).*alpha.^(-1)).*((-1).* ...
        v.^alpha+u.^alpha.*((-1)+v.^alpha)).^(-3).*((-1).*alpha.*(1+alpha) ...
        .*(v.^alpha+alpha.*(v.^alpha+u.^alpha.*((-1)+v.^alpha))).*log(u)+( ...
        -1).*alpha.*(1+alpha).*((-1).*alpha.*v.^alpha+u.^alpha.*(1+alpha+ ...
        alpha.*v.^alpha)).*log(v)+((-1).*v.^alpha+u.^alpha.*((-1)+ ...
        v.^alpha)).*(alpha.^2+(1+alpha).*log((-1)+u.^((-1).*alpha)+v.^(( ...
        -1).*alpha))));


    dlXdmuX2(i)=(muX-2*x)/(muX^3);
    dlYdmuY2(i)=(muY-2*y)/(muY^3);


end


%pmle var

score_muX=dlXdmuX+dcdmuX./c;
score_muY=dlYdmuY+dcdmuY./c;
score_alpha=dcdalpha./c;

Ipmle=[score_muX score_muY score_alpha]'*[score_muX score_muY score_alpha]/N;
pmlevar=inv(Ipmle);


