%matlabpool(8);

truealpha=0.05; %dependence parameter
muX=0.5;      %marginal parameter
muY=1;
N=1e6;      %sample size

seed=1;

[U, V]=plackett_rnd(truealpha,N,seed);

%estimate pseudo alpha 
rho=copulafit('Gaussian',[U V]); 
alpha=rho(1,2);

X = expinv(U,muX);
Y = expinv(V,muY);


dlXdmuX=zeros(N,1);
dlYdmuY=zeros(N,1);
dcdmuX=zeros(N,1);
dcdmuY=zeros(N,1);

c=zeros(N,1);
dcdalpha=zeros(N,1);

dlXdmuX2=zeros(N,1);
dlYdmuY2=zeros(N,1);


for i=1:N

    u=U(i);
    v=V(i);
    x=X(i);
    y=Y(i);

    dlXdmuX(i)=(x-muX)/(muX^2);
    dlYdmuY(i)=(y-muY)/(muY^2);

    dFdmuX=-x*exp(-x/muX)/(muX^2);
    dFdmuY=-y*exp(-y/muY)/(muY^2);

    erciu=erfcinv(2.*u);
    erciv=erfcinv(2.*v);

    dcdu=2.*alpha.*(1+(-1).*alpha.^2).^(-3/2).*exp(((-1)+alpha.^2).^( ...
        -1).*(((-1)+2.*alpha.^2).*erciu.^2+(-2).*alpha.*erciu.*erciv+alpha.^2.*erciv ...
        .^2)).*pi.^(1/2).*(alpha.*erciu+(-1).*erciv);


    dcdv=2.*alpha.*(1+(-1).*alpha.^2).^(-3/2).*exp(((-1)+alpha.^2) ...
        .^(-1).*(alpha.^2.*erciu.^2+(-2).*alpha.*erciu.*erciv+((-1)+2.*alpha.^2).*erciv.^2) ...
        ).*pi.^(1/2).*((-1).*erciu+alpha.*erciv);

    dcdmuX(i)=dcdu*dFdmuX;
    dcdmuY(i)=dcdv*dFdmuY;

    c(i)=copulapdf('Gaussian',[u,v],alpha);

    dcdalpha(i)=(-1).*(1+(-1).*alpha.^2).^(-5/2).*exp(alpha.*((-1)+alpha.^2) ...
        .^(-1).*(alpha.*erciu.^2+(-2).*erciu.*erciv+alpha.*erciv.^2)).*(2.*alpha.* ...
        erciu.^2+(-2).*(1+alpha.^2).*erciu.*erciv+alpha.*((-1)+alpha.^2+2.*erciv.^2));

    dlXdmuX2(i)=(muX-2*x)/(muX^3);
    dlYdmuY2(i)=(muY-2*y)/(muY^3);


end



%pmle var

score_muX=dlXdmuX+dcdmuX./c;
score_muY=dlYdmuY+dcdmuY./c;
score_alpha=dcdalpha./c;

I=[score_muX score_muY score_alpha]'*[score_muX score_muY score_alpha]/N;

pmlevar=inv(Ipmle);


