%Monte Carlo simulations for QMLE and FMLE with Placket copula

N     =  1000;   % Length of simulated series
NumOfExperiments =  1000;    % Number of experiments
seed             =  1;    % Set RNG seed

alpha=0.05; %copula dependence parameter
mu1=0.5;      %parameter of the marginals
mu2=1;

tic


rand ('state', seed);
randn('state', seed);

%5 different estimators 
betaX=zeros(NumOfExperiments,5);
betaY=zeros(NumOfExperiments,5);


for experiment = 1:NumOfExperiments


    [U, V]=plackett_rnd(alpha,N,experiment);


    X = expinv(U,mu1);
    Y = expinv(V,mu2);


    [betaX(experiment,:), betaY(experiment,:)] = Estimate_FMLE_PMLE_QMLE_IQMLE(X, Y);


end


fprintf('Estimat  |    FMLE    | PMLE-Gaus  | PMLE-Cl(r) |    QMLE    |   IQMLE    |    FMLE    | PMLE-Gaus  | PMLE-Cl(r) |    QMLE    |   IQMLE    |  \n');
fprintf('Mean     | %.8f | %.8f | %.8f | %.8f | %.8f | %.8f | %.8f | %.8f | %.8f | %.8f |\n', mean(betaX, 1),mean(betaY, 1));
fprintf('VarxN    | %.8f | %.8f | %.8f | %.8f | %.8f | %.8f | %.8f | %.8f | %.8f | %.8f |\n', std(betaX, 1,1).^2*N,std(betaY, 1,1).^2*N);
fprintf('MSExN    | %.8f | %.8f | %.8f | %.8f | %.8f | %.8f | %.8f | %.8f | %.8f | %.8f |\n', ((mean(betaX, 1)-mu1).^2+std(betaX, 1,1).^2)*N,((mean(betaY, 1)-mu2).^2+std(betaY, 1,1).^2)*N);


fprintf('Elapsed time is %g sec(s)\n', toc); 
