%MonteCarlo simulations for sieve

%Originally this was run on multi-CPU core cluster using Matlab parallel
%toolbox
% 
% parpool(16)

% Set parameter values


N     =  1000;   % Length of simulated series
NumOfExperiments =  1000;    % Number of experiments
seed             =  1;    % Set RNG seed

alpha=0.05; %copula dependence parameter
mu1=0.5;      %parameter of the marginals
mu2=1;        %parameter of the marginals



% 2. Simulate series.

rand ('state', seed);
randn('state', seed);




betaX=zeros(NumOfExperiments,1);
betaY=zeros(NumOfExperiments,1);


logLSMLE=zeros(NumOfExperiments,1);
AIC=zeros(NumOfExperiments,1);
BIC=zeros(NumOfExperiments,1);
ISE=zeros(NumOfExperiments,1);
elapsedTime=zeros(NumOfExperiments,1);


for k=2:15
    
    %parfor was used for speedy computations
    for experiment = 1:NumOfExperiments    

        tic
        [U, V] = plackett_rnd(alpha, N,experiment);
        
        
        X = expinv(U,mu1);
        Y = expinv(V,mu2);
        
               
        % 3. Compute estimates
        
        %note if constraint optimization for sieve is prefered (small J_N) change
        %function Estimate to Estimate_SMLE_Bernstein_cons but it takes longer and does
        %not always converge for larger J_N
        [betaX(experiment), betaY(experiment), c_coef, logLSMLE(experiment), BIC(experiment), AIC(experiment)] = Estimate_SMLE_Bernstein(X, Y, k);
        
        elapsedTime(experiment) = toc;

        ISE(experiment)=copula_ISE_Bernstein(c_coef,k,alpha);

    end
              
    fprintf('%i %7.8f %7.8f %7.8f %7.8f %7.8f %7.8f %7.8f %7.8f %7.8f %7.8f %7.8f %g\n',k,mean(betaX),mean(betaY),var(betaX)*N,var(betaY)*N,((mean(betaX)-mu1)^2+var(betaX))*N,((mean(betaY)-mu2)^2+var(betaY))*N,((mean(betaX)-mu1)^2+var(betaX)+(mean(betaY)-mu2)^2+var(betaY))*N,mean(logLSMLE),mean(AIC),mean(BIC),mean(ISE),mean(elapsedTime));    

end


