%MonteCarlo simulations for sieve

%Originally this was run on multi-CPU core cluster using Matlab parallel
%toolbox
%
%parpool(20)

% Set parameter values


N     =  1000;   % Length of simulated series
NumOfExperiments =  1000;    % Number of experiments
seed             =  1;    % Set RNG seed

alpha=0.05; %copula dependence parameter
mu1=0.5;      %parameter of the marginals
mu2=1;        %parameter of the marginals

% specify basis function from the following list
% PolynBasis - power series (PowPol)
% CosBasis - cosine polynomial (CosPol)
% SinBasis - sine polynomial (SinPol)
% TripolBasis - tigonometric (sin+cos) polynomial (TriPol)
% Spline3Basis - spline basis of order 3 
% Spline4Basis - spline basis of order 4 

formBasis=@PolynBasis;

% 2. Simulate series.

rand ('state', seed);
randn('state', seed);


betaX=zeros(NumOfExperiments,1);
betaY=zeros(NumOfExperiments,1);


logLSMLE=zeros(NumOfExperiments,1);
AIC=zeros(NumOfExperiments,1);
BIC=zeros(NumOfExperiments,1);
ISE=zeros(NumOfExperiments,1);
elapsedTime=zeros(NumOfExperiments,1);

for k=2:15
    
    %parfor was used for speedy computations
    for experiment = 1:NumOfExperiments
        tic
        [U, V] = plackett_rnd(alpha, N,experiment);

        X = expinv(U,mu1);
        Y = expinv(V,mu2);


        m=1000; % mxm - mesh over which intergral is computed

        [UI,VI] = meshgrid(((1:m)-1/2)/m); %avoid 0 and 1 in the mesh, use the middle of the interval

        Integ_Basis=formBasis(UI(:),VI(:),k);


        % 3. Compute estimates

        
        [betaX(experiment), betaY(experiment), c_coef, logLSMLE(experiment), BIC(experiment), AIC(experiment)] = Estimate_SMLE_Tensor_series(X, Y, k, formBasis, Integ_Basis);

        elapsedTime(experiment) = toc;
        ISE(experiment)=copula_ISE_Tensor_series(c_coef,alpha,Integ_Basis,UI(:),VI(:));

    end

    %remove outliers - can arrise due to numerical issues
    betaX=betaX(~isoutlier(betaX));
    betaY=betaY(~isoutlier(betaY));

    fprintf('%i %7.8f %7.8f %7.8f %7.8f %7.8f %7.8f %7.8f %7.8f %7.8f %7.8f %g %7.8f\n',k,mean(betaX),mean(betaY),var(betaX)*N,var(betaY)*N,((mean(betaX)-mu1)^2+var(betaX))*N,((mean(betaY)-mu2)^2+var(betaY))*N,((mean(betaX)-mu1)^2+var(betaX)+(mean(betaY)-mu2)^2+var(betaY))*N,mean(logLSMLE),mean(AIC),mean(BIC),mean(ISE),mean(elapsedTime));

end


